# Generated by roxygen2: do not edit by hand

S3method("[",history_array)
S3method("[[",history_array)
S3method(as.array,history_array)
S3method(as.array,history_list)
S3method(as.list,history_array)
S3method(as.list,history_list)
S3method(length,history_array)
S3method(plot,path_curve)
S3method(plot,path_index)
S3method(print,history_array)
S3method(print,tour_path)
S3method(str,history_array)
export(MIC)
export(TIC)
export(anchored_orthogonal_distance)
export(andrews)
export(angular_breaks)
export(animate)
export(animate_andrews)
export(animate_density2d)
export(animate_depth)
export(animate_dist)
export(animate_faces)
export(animate_groupxy)
export(animate_idx)
export(animate_image)
export(animate_pca)
export(animate_pcp)
export(animate_sage)
export(animate_scatmat)
export(animate_slice)
export(animate_stars)
export(animate_stereo)
export(animate_trails)
export(animate_xy)
export(anomaly_index)
export(areColors)
export(basis_init)
export(basis_random)
export(center)
export(check_dup)
export(cmass)
export(cumulative_radial)
export(dcor2d)
export(dcor2d_2)
export(dependence_tour)
export(display_andrews)
export(display_density2d)
export(display_depth)
export(display_dist)
export(display_faces)
export(display_groupxy)
export(display_idx)
export(display_image)
export(display_pca)
export(display_pcp)
export(display_sage)
export(display_scatmat)
export(display_slice)
export(display_stars)
export(display_stereo)
export(display_trails)
export(display_xy)
export(draw_tour_axes)
export(estimate_eps)
export(find_platform)
export(freeze)
export(frozen_guided_tour)
export(frozen_tour)
export(geodesic_path)
export(grand_tour)
export(guided_anomaly_tour)
export(guided_section_tour)
export(guided_tour)
export(holes)
export(interpolate)
export(is_orthonormal)
export(lda_pp)
export(linear_breaks)
export(little_tour)
export(local_tour)
export(loess2d)
export(mahal_dist)
export(manual_slice)
export(mapColors)
export(mapShapes)
export(new_geodesic_path)
export(new_tour)
export(norm_bin)
export(norm_kol)
export(normalise)
export(orthonormalise)
export(orthonormalise_by)
export(path_curves)
export(path_dist)
export(path_index)
export(paths_index)
export(pda_pp)
export(planned2_tour)
export(planned_tour)
export(proj_dist)
export(radial_tour)
export(render)
export(render_anim)
export(render_gif)
export(render_proj)
export(rescale)
export(save_history)
export(search_better)
export(search_better_random)
export(search_geodesic)
export(search_jellyfish)
export(search_polish)
export(search_posse)
export(skewness)
export(slice_index)
export(sphere_data)
export(splines2d)
export(stringy)
export(thaw)
importFrom(grDevices,dev.cur)
importFrom(grDevices,dev.flush)
importFrom(grDevices,dev.hold)
importFrom(grDevices,dev.off)
importFrom(grDevices,hcl)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,contour)
importFrom(graphics,hist)
importFrom(graphics,image)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,pairs)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,segments)
importFrom(graphics,stars)
importFrom(graphics,text)
importFrom(stats,loess)
importFrom(stats,mahalanobis)
importFrom(stats,na.omit)
importFrom(stats,qchisq)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,var)
importFrom(utils,globalVariables)
importFrom(utils,tail)
