% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/interesting-indices.r
\name{stringy}
\alias{stringy}
\title{Scagnostic indexes.}
\usage{
stringy()
}
\description{
Compute the scagnostic measures from the cassowaryr package
}
