% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/util.r
\name{areColors}
\alias{areColors}
\title{Test if all entries are colors}
\usage{
areColors(x)
}
\arguments{
\item{x}{vector}
}
\description{
Test if all entries are colors
}
