% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/util.r
\name{blank_plot}
\alias{blank_plot}
\title{Set up a blank plot to display data projections}
\usage{
blank_plot(...)
}
\description{
Set up a blank plot to display data projections
}
\keyword{internal}
